==> haskell-yesod-static-1.5.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.2
id: yesod-static-1.5.2-FndiUgBXRQ44nTyVPyOOqk
key: yesod-static-1.5.2-FndiUgBXRQ44nTyVPyOOqk
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
abi: a6da87ff190fdb78819274a177468bd4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-static-1.5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-static-1.5.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-static-1.5.2
hs-libraries: HSyesod-static-1.5.2-FndiUgBXRQ44nTyVPyOOqk
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    conduit-extra-1.1.15-9BEhw2PHvUTFj1lUJfHKAK containers-0.5.7.1
    cryptohash-0.11.9-7DFTpGt1NsYGD2GaWWablc
    cryptohash-conduit-0.1.1-3eA64opzMSbIWEZqnQMPNo
    css-text-0.1.2.2-ID6dFT9pfdSA5gvNaIq3qA
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ filepath-1.4.1.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hjsmin-0.2.0.2-BEH1Ch8p8LmFbydn4PrYHw
    http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp process-1.4.2.0
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    wai-3.2.1.1-G3x7tNXaUUGBY6K4SzJOAN
    wai-app-static-3.1.6.1-GvhMYkyX5X8ApwRP4HJRmx
    yesod-core-1.4.31-tuwr0E3PIcCefINtIIL0h
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.5.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.2
id: yesod-static-1.5.2-1jX2WJgTGDtFXuTjOZsQmq
key: yesod-static-1.5.2-1jX2WJgTGDtFXuTjOZsQmq
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
abi: af0edab592f09180caa314f74116bd76
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-static-1.5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-static-1.5.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-static-1.5.2
hs-libraries: HSyesod-static-1.5.2-1jX2WJgTGDtFXuTjOZsQmq
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    conduit-extra-1.1.15-9BEhw2PHvUTFj1lUJfHKAK containers-0.5.7.1
    cryptohash-0.11.9-7DFTpGt1NsYGD2GaWWablc
    cryptohash-conduit-0.1.1-3eA64opzMSbIWEZqnQMPNo
    css-text-0.1.2.2-ID6dFT9pfdSA5gvNaIq3qA
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ filepath-1.4.1.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hjsmin-0.2.0.2-BEH1Ch8p8LmFbydn4PrYHw
    http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp process-1.4.2.0
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    wai-3.2.1.1-G3x7tNXaUUGBY6K4SzJOAN
    wai-app-static-3.1.6.1-Lb5GRQd47WT3Tpq1UzsOaH
    yesod-core-1.4.32-Ajy1QhtrwXmGWhrtXUYXMc
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
